import { useState } from "react";
import { downloadFile } from "@/utils/common";
import useShowToast from "@/app/hooks/useShowToast";
import { useGeneral } from "@/contexts/GeneralContext";

interface UseExportHandlerParams {
  onExport: (params: Record<string, string>) => Promise<any>;
}

const useExportHandler = ({ onExport }: UseExportHandlerParams) => {
  const [isExporting, setIsExporting] = useState(false);
  const { currentUser } = useGeneral();
  const showToast = useShowToast();

  const handleExport = async () => {
    setIsExporting(true);
    try {
      const updatedQuery = new URLSearchParams(window.location.search);
      updatedQuery.set("export", "true");

      // Call API to request export link
      const response = await onExport(
        Object.fromEntries(updatedQuery.entries())
      );
      console.log(response);
      if (response?.data?.id) {
        // Trigger another API to download the file
        await downloadFile(response.data.id, "download.xlsx", currentUser.token);
        showToast("Export Successful", "Your file has been downloaded.", "success");
      } else {
        console.log('****************** response ******************');
        console.log(response);
        if (response?.message && response?.message == 'Consumer export is in process please check download page.') {
          var message = response?.message;
          showToast("Export in Process", message, "success");
        } else {
          throw new Error("Export failed. No file link received.");
        } 
      }
    } catch (error: any) {
      showToast("Export Failed", error.message, "error");
    } finally {
      setIsExporting(false);
    }
  };

  return {
    isExporting,
    handleExport,
  };
};

export default useExportHandler;
